---
description: CURSOR UTILS INTEGRATION
globs: *
---

**Version:** {version}  
**Installed:** {timestamp}  
**Path:** {install_path}

**Web Command aka `Ask Perplexity`:**{{
`cursor-utils web "[your question]"` - Get answers from the web using Perplexity AI (e.g., `cursor-utils web "latest Python release including key changes?"`)
when using web for complex queries suggest writing the output to a file somewhere like `local-research/[query summary].md`.
Note: The directory will be created if it doesn't exist, and filenames will be automatically sanitized.
}}
**Repo Command:**{{
`cursor-utils repo "[your query]"` - Get context-aware answers about the current repository using Google Gemini
`cursor-utils repo https://github.com/user/repo Generate documentation for my codebase.` - Analyze a remote GitHub repository
}}
**Gemini Command aka `Ask Gemini`:**{{
`cursor-utils gemini "[your query]"` - Query the Gemini API directly and stream responses
`cursor-utils gemini "[your query]" --append [file]` - Query the Gemini API 
directly and stream responses using a local file as context (e.g., 
`cursor-utils gemini "explain this module" --append /src/repo.py`)
# Gemini Command Options:
- `-a / --append=[path-to-file]`: Attach a file to provide context for the query
}}
**GitHub Command:**{{
`cursor-utils github analyze [OWNER] [REPO]` - Analyze a GitHub repository structure and provide insights
`cursor-utils github pr [OWNER] [REPO]` - Generate a PR description from commits
`cursor-utils github issues [OWNER] [REPO]` - Summarize GitHub issues with AI-powered insights
`cursor-utils github setup NAME` - Set up a new GitHub repository with best practices
# GitHub Command Options:
## Analyze:
- `--detailed/--summary`: Show detailed analysis including contributors, languages, and recent commits
## PR:
- `--branch TEXT`: Branch to create PR from (default: main)
- `--title TEXT`: PR title (optional, generated from commits if not provided)
- `--base TEXT`: Base branch (default: main)
## Issues:
- `--state [open|closed|all]`: Filter issues by state (default: open)
- `--label TEXT`: Filter issues by label (can be used multiple times)
- `--limit INTEGER`: Maximum number of issues to summarize (default: 10)
## Setup:
- `--private/--public`: Create a private repository (default: private)
- `--template TEXT`: Template to use for repository setup
# Configuration:
GitHub settings can be configured via `cursor-utils config` or in the cursor-utils.yaml file:
- `token_source`: Source for GitHub token (env or config)
- `default_owner`: Default GitHub owner/organization
- `default_repo`: Default GitHub repository
- `template_dir`: Directory for GitHub templates
}}
**Install Command:**{{
`cursor-utils install` - Set up cursor-utils in your project
# Install Command Features:
- Creates necessary configuration files
- Sets up API keys for:
  - Perplexity AI (Enhanced web search)
  - Google Gemini (Repository analysis)
  - GitHub (PR/issue management)
- Generates cursor rules and templates
- Configures environment variables
# Install CommandOptions:
- `--debug`: Enable debug output
# Configuration Files Created:
- `~/.cursor-utils.toml`: Global configuration
- `~/.env`: API keys and secrets
- `.cursor/rules/default.mdc`: Rule templates
- Cache: `~/.cursor-utils/cache/`
- Logs: `~/.cursor-utils/logs/`
}}
**cursor-utils.toml Config Options:**{{
  **Model Parameters:**
# (Web) PERPLEXITY MODELS:
- sonar (Default for basic queries)
- sonar-pro (Enhanced comprehension)
- sonar-reasoning (Better analysis)
- sonar-reasoning-pro (Best for complex topics)
# (Web) PERPLEXITY MODES:
- copilot (Default, interactive)
- concise (Brief answers)
# (Web) PERPLEXITY SEARCH FOCUSES:
- internet (Default)
- scholar (Academic)
- wolfram (Mathematical)
- writing (Content creation)
- youtube (Video content)
- reddit (Community discussions)
# GEMINI MODELS:
- gemini-2.0-pro-exp-02-05 (Default, best for code)
- gemini-2.0-flash (Faster responses)
- gemini-2.0-flash-thinking-exp (Deep reasoning model)
# (Gemini) TOKEN LIMITS:
- Default: 8000 tokens
- Fallback: 4000 tokens (if hitting errors)
- Adjust with --max-tokens option
}}
**File Size Limits:**{{
  - Repository Analysis: Up to 2GB per file, 20GB total repository size
  - File Attachments: Text files of any reasonable size
  - Browser Downloads: Limited by available system memory
}}
**Best Practices:**{{
  1. Start with default models, adjust if needed
  2. Use file attachments for context when relevant
  3. Save long outputs to files with --save-to
  4. Enable debug mode with --debug for troubleshooting
  5. Check logs for detailed error information
}}
**Remember:**{{
  You're part of a team of expert AI agents. Work together, share knowledge, and iterate to solve complex problems.
}}
---
*This documentation was automatically generated by Cursor Utils version {version} at {timestamp}* 